summaryrefslogtreecommitdiffstats
path: root/src/ChunkMap.h
diff options
context:
space:
mode:
authorHowaner <franzi.moos@googlemail.com>2014-02-19 14:45:09 +0100
committerTheJumper <maximilian.springer@web.de>2014-02-23 19:50:50 +0100
commit1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b (patch)
tree617bf18a768a493c2cd428297168f57df0901c26 /src/ChunkMap.h
parentAdd break to Protocol17x.cpp and use new comment delimiter (diff)
downloadcuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar.gz
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar.bz2
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar.lz
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar.xz
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.tar.zst
cuberite-1f726b7d9dade75d8f7a3e105f3c9689a1ef0e0b.zip
Diffstat (limited to '')
-rw-r--r--src/ChunkMap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ChunkMap.h b/src/ChunkMap.h
index d6036d828..9df68c403 100644
--- a/src/ChunkMap.h
+++ b/src/ChunkMap.h
@@ -25,7 +25,7 @@ class cDropSpenserEntity;
class cFurnaceEntity;
class cNoteEntity;
class cCommandBlockEntity;
-class cSkullEntity;
+class cMobHeadEntity;
class cPawn;
class cPickup;
class cChunkDataSerializer;
@@ -44,7 +44,7 @@ typedef cItemCallback<cDropSpenserEntity> cDropSpenserCallback;
typedef cItemCallback<cFurnaceEntity> cFurnaceCallback;
typedef cItemCallback<cNoteEntity> cNoteBlockCallback;
typedef cItemCallback<cCommandBlockEntity> cCommandBlockCallback;
-typedef cItemCallback<cSkullEntity> cSkullBlockCallback;
+typedef cItemCallback<cMobHeadEntity> cMobHeadBlockCallback;
typedef cItemCallback<cChunk> cChunkCallback;
@@ -256,8 +256,8 @@ public:
/** Calls the callback for the command block at the specified coords; returns false if there's no command block at those coords or callback returns true, returns true if found */
bool DoWithCommandBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cCommandBlockCallback & a_Callback); // Lua-accessible
- /** Calls the callback for the skull block at the specified coords; returns false if there's no skull block at those coords or callback returns true, returns true if found */
- bool DoWithSkullBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cSkullBlockCallback & a_Callback); // Lua-accessible
+ /** Calls the callback for the mob head block at the specified coords; returns false if there's no mob head block at those coords or callback returns true, returns true if found */
+ bool DoWithMobHeadBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cMobHeadBlockCallback & a_Callback); // Lua-accessible
/** Retrieves the test on the sign at the specified coords; returns false if there's no sign at those coords, true if found */
bool GetSignLines (int a_BlockX, int a_BlockY, int a_BlockZ, AString & a_Line1, AString & a_Line2, AString & a_Line3, AString & a_Line4); // Lua-accessible